function [ret,x0,str,ts,xts]=simclas9(t,x,u,flag);
%SIMCLAS9	is the M-file description of the SIMULINK system named SIMCLAS9.
%	The block-diagram can be displayed by typing: SIMCLAS9.
%
%	SYS=SIMCLAS9(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMCLAS9 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMCLAS9 with a FLAG of zero:
%	[SIZES]=SIMCLAS9([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1267,977])
     open_system(sys)
end;
set_param(sys,'BackGround',2)
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim')
set_param(sys,'Min step size', 'tsim/1000')
set_param(sys,'Max step size', 'tsim/100')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[187,484,901,734])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'hide name',0,...
		'position',[495,162,520,188])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'hide name',0,...
		'Value','4e-8',...
		'Mask Display','Couple aerod',...
		'position',[370,164,470,186])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain4'])
set_param([sys,'/','Subsystem/Gain4'],...
		'hide name',0,...
		'Gain','0',...
		'position',[495,72,520,98])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain3'])
set_param([sys,'/','Subsystem/Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[495,117,520,143])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\nactuateurs',...
		'position',[370,116,470,144])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum1'])
set_param([sys,'/','Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[550,60,570,200])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\ninterne',...
		'position',[370,69,470,101])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[610,120,630,140])
add_line([sys,'/','Subsystem'],[475,175;490,175])
add_line([sys,'/','Subsystem'],[475,130;490,130])
add_line([sys,'/','Subsystem'],[475,85;490,85])
add_line([sys,'/','Subsystem'],[525,85;545,85])
add_line([sys,'/','Subsystem'],[525,175;545,175])
add_line([sys,'/','Subsystem'],[525,130;545,130])
add_line([sys,'/','Subsystem'],[575,130;605,130])
set_param([sys,'/','Subsystem'],...
		'Mask Display','COUPLES\nPERTURBATEURS')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[630,509,755,561])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','teta_zero',...
		'position',[985,408,1035,452])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','teta_prim0+0.002',...
		'position',[890,408,935,452])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[550,512,785,642])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain4'])
set_param([sys,'/','Subsystem2/Gain4'],...
		'hide name',0,...
		'position',[165,50,200,90])

add_block('built-in/Fcn',[sys,'/','Subsystem2/Fcn'])
set_param([sys,'/','Subsystem2/Fcn'],...
		'Expr','-3*vitesse_rotation^2*(Ir-Il)*u(1)',...
		'position',[60,56,135,84])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/out_1'],...
		'position',[215,60,235,80])
add_line([sys,'/','Subsystem2'],[140,70;160,70])
add_line([sys,'/','Subsystem2'],[40,70;55,70])
add_line([sys,'/','Subsystem2'],[205,70;210,70])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','GRADIENT\nDE\nGRAVITE')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[670,574,755,616])

add_block('built-in/Note',[sys,'/','Couples perturbateurs  pris en compte ( couple aerodynamique )'])
set_param([sys,'/','Couples perturbateurs  pris en compte ( couple aerodynamique )'],...
		'ForeGround',1,...
		'position',[405,765,410,770])

add_block('built-in/Note',[sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']])
set_param([sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']],...
		'ForeGround',1,...
		'position',[365,815,370,820])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','Cgg',...
		'buffer','points_trace',...
		'position',[805,580,885,610])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','++++',...
		'position',[805,354,830,501])

add_block('built-in/Gain',[sys,'/','1//It'])
set_param([sys,'/','1//It'],...
		'ForeGround',7,...
		'Gain','1/It',...
		'position',[850,420,870,440])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[140,183,170,287])

add_block('built-in/Note',[sys,'/','SIMULATION'])
set_param([sys,'/','SIMULATION'],...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[1090,65,1095,70])

add_block('built-in/Note',[sys,'/','simclas9.m'])
set_param([sys,'/','simclas9.m'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[1095,90,1100,95])


%     Subsystem  ['Inner',13,'Product'].

new_system([sys,'/',['Inner',13,'Product']])
set_param([sys,'/',['Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Inner',13,'Product/Product']])
set_param([sys,'/',['Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Inner',13,'Product/Sum']])
set_param([sys,'/',['Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Inner',13,'Product/out_1']])
set_param([sys,'/',['Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product/in_2']])
set_param([sys,'/',['Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product/in_1']])
set_param([sys,'/',['Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Inner',13,'Product'].

set_param([sys,'/',['Inner',13,'Product']],...
		'position',[735,353,780,397])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','cpldesat',...
		'buffer','points_trace',...
		'position',[820,300,900,330])

add_block('built-in/Transport Delay',[sys,'/','Retard3'])
set_param([sys,'/','Retard3'],...
		'Delay Time','0.2',...
		'position',[625,454,685,486])

add_block('built-in/Constant',[sys,'/',['Angle  de ',13,'rfrence']])
set_param([sys,'/',['Angle  de ',13,'rfrence']],...
		'hide name',0,...
		'Value','consigne_tangage*0',...
		'Mask Display','CONSIGNE',...
		'position',[25,191,100,229])

add_block('built-in/Gain',[sys,'/','Conversion rd//'])
set_param([sys,'/','Conversion rd//'],...
		'ForeGround',7,...
		'Gain','180/pi',...
		'position',[1110,512,1140,538])

add_block('built-in/Note',[sys,'/',['Gradient de gravit pris en compte ( sortie du couple  Cgg )',13,'']])
set_param([sys,'/',['Gradient de gravit pris en compte ( sortie du couple  Cgg )',13,'']],...
		'ForeGround',1,...
		'position',[390,745,395,750])

add_block('built-in/Note',[sys,'/',['Mode petits angles, jusqu'' 20( pas ncesaire en tangage seul )']])
set_param([sys,'/',['Mode petits angles, jusqu'' 20( pas ncesaire en tangage seul )']],...
		'ForeGround',1,...
		'position',[405,790,410,795])

add_block('built-in/Relay',[sys,'/','Relay'])
set_param([sys,'/','Relay'],...
		'orientation',1,...
		'hide name',0,...
		'On_switch_value','rotation_maximale*0.8',...
		'Off_switch_value','-rotation_maximale*0.8',...
		'Mask Display','DETECTION\nSATURATION')
set_param([sys,'/','Relay'],...
		'position',[594,290,686,340])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[590,124,695,156])

add_block('built-in/Note',[sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']])
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']],...
		'ForeGround',1)
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']],...
		'Font Name','Arial')
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']],...
		'Font Weight','bold')
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']],...
		'Font Size',18)
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE',13,'SUIVI DE LA VITESSE DE LA ROUE. DESATURATION',13,'MODELE REGULATION PID']],...
		'position',[555,0,560,5])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[157,392,766,747])

add_block('built-in/Note',[sys,'/','Subsystem3/Ecart teta_ref - teta'])
set_param([sys,'/','Subsystem3/Ecart teta_ref - teta'],...
		'position',[70,40,75,45])

add_block('built-in/Note',[sys,'/','Subsystem3/Rappel proportionnel'])
set_param([sys,'/','Subsystem3/Rappel proportionnel'],...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/','Subsystem3/gain 0 ou 1'])
set_param([sys,'/','Subsystem3/gain 0 ou 1'],...
		'position',[255,207,285,233])

add_block('built-in/Outport',[sys,'/','Subsystem3/commande_pid'])
set_param([sys,'/','Subsystem3/commande_pid'],...
		'position',[545,140,565,160])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain'])
set_param([sys,'/','Subsystem3/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PD',...
		'position',[160,61,235,99])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[55,70,75,90])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem3/Intgrateur'])
set_param([sys,'/','Subsystem3/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[1/1000000]',...
		'Denominator','[1 0]',...
		'position',[155,199,225,241])

add_block('built-in/Derivative',[sys,'/','Subsystem3/Derivative'])
set_param([sys,'/','Subsystem3/Derivative'],...
		'position',[155,130,200,170])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem3/Filtre passe bas'])
set_param([sys,'/','Subsystem3/Filtre passe bas'],...
		'Denominator','[1 1/0.8]',...
		'position',[435,125,495,175])

add_block('built-in/Sum',[sys,'/','Subsystem3/Sum'])
set_param([sys,'/','Subsystem3/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Note',[sys,'/',['Subsystem3/Rappel',13,'proportionnel']])
set_param([sys,'/',['Subsystem3/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[255,10,260,15])

add_block('built-in/Note',[sys,'/','Subsystem3/ROUE'])
set_param([sys,'/','Subsystem3/ROUE'],...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain1'])
set_param([sys,'/','Subsystem3/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PD',...
		'position',[235,129,290,171])
add_line([sys,'/','Subsystem3'],[290,220;320,220])
add_line([sys,'/','Subsystem3'],[230,220;250,220])
add_line([sys,'/','Subsystem3'],[295,150;320,150])
add_line([sys,'/','Subsystem3'],[205,150;230,150])
add_line([sys,'/','Subsystem3'],[240,80;320,80])
add_line([sys,'/','Subsystem3'],[80,80;155,80])
add_line([sys,'/','Subsystem3'],[360,150;430,150])
add_line([sys,'/','Subsystem3'],[500,150;540,150])
add_line([sys,'/','Subsystem3'],[110,80;110,220;150,220])
add_line([sys,'/','Subsystem3'],[110,150;150,150])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','P.I.D')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'position',[215,205,310,265])

add_block('built-in/Integrator',[sys,'/','Integrator2'])
set_param([sys,'/','Integrator2'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','rotation_initiale*0-rotation_maximale',...
		'position',[615,188,660,232])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','1/J',...
		'position',[555,190,590,230])

add_block('built-in/Gain',[sys,'/',['Inversion',13,'signe']])
set_param([sys,'/',['Inversion',13,'signe']],...
		'ForeGround',7,...
		'Gain','-1',...
		'position',[505,197,535,223])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[380,351,1239,688])

add_block('built-in/Note',[sys,'/',['Subsystem1/Le rglage du gain par rapport  gain_saturation permet ',13,'de rduire ou allonger la dure de la dsaturation',13,'ce qui modifie en proportion le couple sur le satellite et la roue']])
set_param([sys,'/',['Subsystem1/Le rglage du gain par rapport  gain_saturation permet ',13,'de rduire ou allonger la dure de la dsaturation',13,'ce qui modifie en proportion le couple sur le satellite et la roue']],...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem1/Le rglage du gain par rapport  gain_saturation permet ',13,'de rduire ou allonger la dure de la dsaturation',13,'ce qui modifie en proportion le couple sur le satellite et la roue']],...
		'Font Size',16)
set_param([sys,'/',['Subsystem1/Le rglage du gain par rapport  gain_saturation permet ',13,'de rduire ou allonger la dure de la dsaturation',13,'ce qui modifie en proportion le couple sur le satellite et la roue']],...
		'position',[360,235,365,240])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem1/MATLAB Fcn'])
set_param([sys,'/','Subsystem1/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[495,335,670,385])

add_block('built-in/Clock',[sys,'/','Subsystem1/Clock'])
set_param([sys,'/','Subsystem1/Clock'],...
		'position',[440,350,460,370])

add_block('built-in/To Workspace',[sys,'/',['Subsystem1/Carr du champ ',13,'magntique']])
set_param([sys,'/',['Subsystem1/Carr du champ ',13,'magntique']],...
		'mat-name','b2',...
		'position',[495,172,545,188])

add_block('built-in/Gain',[sys,'/','Subsystem1/Gain1'])
set_param([sys,'/','Subsystem1/Gain1'],...
		'Gain','gain_desaturation',...
		'position',[475,97,555,143])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/To Workspace'])
set_param([sys,'/','Subsystem1/To Workspace'],...
		'mat-name','couple_desat',...
		'position',[640,50,770,100])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[615,110,635,130])

add_block('built-in/Fcn',[sys,'/','Subsystem1/Fcn'])
set_param([sys,'/','Subsystem1/Fcn'],...
		'Expr','u(1)^2+u(2)^2+u(3)^2',...
		'position',[380,99,420,141])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem1/MATLAB Fcn1'])
set_param([sys,'/','Subsystem1/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[125,95,300,145])

add_block('built-in/Clock',[sys,'/','Subsystem1/Clock1'])
set_param([sys,'/','Subsystem1/Clock1'],...
		'position',[65,110,85,130])
add_line([sys,'/','Subsystem1'],[560,120;610,120])
add_line([sys,'/','Subsystem1'],[425,120;470,120])
add_line([sys,'/','Subsystem1'],[440,120;440,180;490,180])
add_line([sys,'/','Subsystem1'],[585,120;585,75;635,75])
add_line([sys,'/','Subsystem1'],[465,360;490,360])
add_line([sys,'/','Subsystem1'],[90,120;120,120])
add_line([sys,'/','Subsystem1'],[305,120;375,120])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','COUPLE\nDESATURATION')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[580,358,695,412])

add_block('built-in/Gain',[sys,'/',['Inversion',13,'signe1']])
set_param([sys,'/',['Inversion',13,'signe1']],...
		'orientation',1,...
		'ForeGround',7,...
		'Gain','-1',...
		'position',[725,235,755,265])

add_block('built-in/Note',[sys,'/',['La dtection en saturation',13,'est ralise par un "relay"',13,'']])
set_param([sys,'/',['La dtection en saturation',13,'est ralise par un "relay"',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',16,...
		'Mask Display','RELAY de dtection\vitesse maximum')
set_param([sys,'/',['La dtection en saturation',13,'est ralise par un "relay"',13,'']],...
		'position',[215,335,220,340])


%     Subsystem  'Teta en degrs)'.

new_system([sys,'/','Teta en degrs)'])
set_param([sys,'/','Teta en degrs)'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Teta en degrs)/x'])
set_param([sys,'/','Teta en degrs)/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Teta en degrs)/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Teta en degrs)/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Teta en degrs)'],[90,65;125,65])
set_param([sys,'/','Teta en degrs)'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Teta en degrs)'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Teta en degrs)'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Teta en degrs)'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Teta en degrs)'],...
		'Mask Entries','5000\/-10\/10\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Teta en degrs)'.

set_param([sys,'/','Teta en degrs)'],...
		'position',[1185,506,1215,544])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[775,130,795,150])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[875,128,925,152])

add_block('built-in/Gain',[sys,'/',['Conversion ',13,'rd//s tours//mn']])
set_param([sys,'/',['Conversion ',13,'rd//s tours//mn']],...
		'ForeGround',7,...
		'Gain','30/pi',...
		'position',[920,197,950,223])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[990,195,1070,225])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','teta',...
		'buffer','points_trace',...
		'position',[1105,415,1185,445])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','tetaprime',...
		'buffer','points_trace',...
		'position',[1100,369,1185,401])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir la courbe\n\nteta (rd)',...
		'Mask Dialogue','eval(''plot(temps,teta);grid;'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1075,655,1250,716])

add_block('built-in/Note',[sys,'/',['LE COUPLE DE DESATURATION ',13,'',13,'EST PRIS EGAL   -sgn(wmax)GB ',13,'',13,'EN VERSION SIMPLIFIEE']])
set_param([sys,'/',['LE COUPLE DE DESATURATION ',13,'',13,'EST PRIS EGAL   -sgn(wmax)GB ',13,'',13,'EN VERSION SIMPLIFIEE']],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Underline',1)
set_param([sys,'/',['LE COUPLE DE DESATURATION ',13,'',13,'EST PRIS EGAL   -sgn(wmax)GB ',13,'',13,'EN VERSION SIMPLIFIEE']],...
		'Font Size',16,...
		'position',[310,500,315,505])

add_block('built-in/Transport Delay',[sys,'/','Retard2'])
set_param([sys,'/','Retard2'],...
		'orientation',2,...
		'Delay Time','0.2',...
		'Initial Input','teta_zero',...
		'position',[470,639,515,671])

add_block('built-in/Note',[sys,'/','Roue relle = Rponses  des capteurs  de position, de vitesse, et de la roue avec retards'])
set_param([sys,'/','Roue relle = Rponses  des capteurs  de position, de vitesse, et de la roue avec retards'],...
		'ForeGround',1,...
		'position',[390,725,395,730])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Initialisation par\n\nscaodat9.m',...
		'Mask Dialogue','eval(''scaodat9'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1075,580,1240,641])

add_block('built-in/Note',[sys,'/','INITIALISATION:'])
set_param([sys,'/','INITIALISATION:'],...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[870,670,875,675])

add_block('built-in/Note',[sys,'/','Rgulation roue de type PD ou PID (rglage sur le modle )'])
set_param([sys,'/','Rgulation roue de type PD ou PID (rglage sur le modle )'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[345,685,350,690])

add_block('built-in/Note',[sys,'/',[' Paramtres particuliers par  scaodat9.m',13,' dans l''espace Matlab ou un',13,'diteur de texte (notepad )']])
set_param([sys,'/',[' Paramtres particuliers par  scaodat9.m',13,' dans l''espace Matlab ou un',13,'diteur de texte (notepad )']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',[' Paramtres particuliers par  scaodat9.m',13,' dans l''espace Matlab ou un',13,'diteur de texte (notepad )']],...
		'position',[855,705,860,710])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Voir la courbe\n\nVitesse roue ( tr/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;'')')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1075,740,1250,801])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir la courbe\n\nCouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1075,815,1250,876])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\ntetaprime (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,tetaprime);grid;'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,815,1040,876])
add_line(sys,[940,430;980,430])
add_line(sys,[1040,430;1100,430])
add_line(sys,[105,210;135,210])
add_line(sys,[800,140;870,140])
add_line(sys,[175,235;210,235])
add_line(sys,[690,470;745,470;745,410;800,410])
add_line(sys,[760,595;800,595])
add_line(sys,[1040,430;1060,430;1060,655;615,655;615,595;665,595])
add_line(sys,[665,210;915,210])
add_line(sys,[595,210;610,210])
add_line(sys,[785,595;785,480;800,480])
add_line(sys,[835,430;845,430])
add_line(sys,[875,430;885,430])
add_line(sys,[785,375;800,375])
add_line(sys,[700,385;730,385])
add_line(sys,[785,375;785,315;815,315])
add_line(sys,[540,210;550,210])
add_line(sys,[640,345;705,345;705,365;730,365])
add_line(sys,[1145,525;1180,525])
add_line(sys,[740,270;740,275;640,285])
add_line(sys,[760,535;775,535;775,445;800,445])
add_line(sys,[615,655;520,655])
add_line(sys,[465,655;80,655;80,260;135,260])
add_line(sys,[315,235;345,235;345,470;620,470])
add_line(sys,[435,470;435,140;585,140])
add_line(sys,[435,210;500,210])
add_line(sys,[1060,525;1105,525])
add_line(sys,[740,210;740,230])
add_line(sys,[955,210;985,210])
add_line(sys,[940,430;940,385;1095,385])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
